@@ -35,7 +35,7 @@ def uniaddr(addr):
 
 
 def mail(
-        host='mail.apache.org:2025',
+        host='mail-relay.apache.org:587',
         sender="Apache Infrastructure <users@infra.apache.org>",
         recipient=None,
         recipients=None,
@@ -96,5 +96,6 @@ Content-Transfer-Encoding: 8bit
     msg = msg.encode('utf-8', errors='replace')
     # Try to dispatch message, do a raw fail if stuff happens.
     smtp_object = smtplib.SMTP(host)
+    smtp_object.starttls()
     # Note that we're using the raw sender here...
     smtp_object.sendmail(sender, recipients, msg)
